@@ -24,14 +24,13 @@
 #include <openvpn/common/rc.hpp>
 #include <openvpn/acceptor/base.hpp>
 
-namespace openvpn
+namespace openvpn {
+// generic structure implemented by the various proxies used by PGProxy
+struct ProxyListener : public Acceptor::ListenerBase
 {
-  // generic structure implemented by the various proxies used by PGProxy
-  struct ProxyListener : public Acceptor::ListenerBase
-  {
     typedef RCPtr<ProxyListener> Ptr;
 
     virtual void start() = 0;
     virtual void stop() = 0;
-  };
-}
+};
+} // namespace openvpn
